==> react-native-neurosdk2-1.0.26.tgz: package/android/src/main/java/com/neurosdk2/Headphones2Impl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertFPGData;
import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.ConvertReactToBoolArray;
import static com.neurosdk2.Utils.ConvertReactToIntArray;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.Headphones2;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.FPGData;
import com.neurosdk2.neuro.types.Headphones2AmplifierParam;
import com.neurosdk2.neuro.types.Headphones2ResistData;
import com.neurosdk2.neuro.types.Headphones2SignalData;
import com.neurosdk2.neuro.types.IrAmplitude;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.RedAmplitude;
public class Headphones2Impl extends AFullSensor{

    public Headphones2Impl(Sensor sensor, String guid, ReactApplicationContext context){
        this.sensor = sensor;
        this.guid = guid;
        this.reactContext = context;
        addCallbacks();
    }

    @Override
    protected void addCallbacks() {
        super.addCallbacks();
        ((Headphones2)sensor).signalDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray signalArray = Arguments.createArray();
            for (Headphones2SignalData signal : data) {
                WritableMap map = Arguments.createMap();
                map.putInt("PackNum", signal.getPackNum());
                map.putInt("Marker", signal.getMarker());
                map.putDouble("Ch1", signal.getCh1());
                map.putDouble("Ch2", signal.getCh2());
                map.putDouble("Ch3", signal.getCh3());
                map.putDouble("Ch4", signal.getCh4());
                signalArray.pushMap(map);
            }
            result.putArray(DATA_ID, signalArray);
            sendEvent(reactContext, Constants.HEADPHONES2_SIGNAL_RECEIVED_EVENT_NAME.raw(), result);
        };
        ((Headphones2)sensor).resistDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for(Headphones2ResistData resists : data){
                WritableMap map = Arguments.createMap();
                map.putInt("PackNum", resists.getPackNum());
                map.putDouble("Ch1", resists.getCh1());
                map.putDouble("Ch2", resists.getCh2());
                map.putDouble("Ch3", resists.getCh3());
                map.putDouble("Ch4", resists.getCh4());
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            sendEvent(reactContext, Constants.HEADPHONES2_RESIST_RECEIVED_EVENT_NAME.raw(), result);
        };
        ((Headphones2)sensor).fpgDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for (FPGData fpgData : data) {
                WritableMap map = Arguments.createMap();
                ConvertFPGData(fpgData, map);
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            sendEvent(reactContext, Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
        };
        ((Headphones2)sensor).memsDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for (MEMSData memsData : data) {
                WritableMap map = Arguments.createMap();
                ConvertMEMSData(memsData, map);
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
        };
        ((Headphones2)sensor).ampModeChanged = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            result.putInt(DATA_ID, data.index());
            sendEvent(reactContext,Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
        };
    }

    @Override
    protected void removeCallbacks() {
        super.removeCallbacks();
        ((Headphones2)sensor).signalDataReceived = null;
        ((Headphones2)sensor).resistDataReceived = null;
        ((Headphones2)sensor).fpgDataReceived = null;
        ((Headphones2)sensor).memsDataReceived = null;
        ((Headphones2)sensor).ampModeChanged = null;
    }

    @Override
    protected String getSensorName() {
        return "Headphones2";
    }

    @Override
    public int getSamplingFrequencyMEMS() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyMEMS().index();
    }

    @Override
    public int getSamplingFrequencyFPG() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyFPG().index();
    }

    @Override
    public int getSamplingFrequencyResist() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyResist().index();
    }

    @Override
    public int getIrAmplitude() throws Exception {
        return ((Headphones2)sensor).getIrAmplitude().index();
    }

    @Override
    public void setIrAmplitude(int amp) throws Exception {
        ((Headphones2)sensor).setIrAmplitude(IrAmplitude.indexOf(amp));
    }

    @Override
    public int getRedAmplitude() throws Exception {
        return ((Headphones2)sensor).getRedAmplitude().index();
    }

    @Override
    public void setRedAmplitude(int amp) throws Exception {
        ((Headphones2)sensor).setRedAmplitude(RedAmplitude.indexOf(amp));
    }

    @Override
    public int getAmpMode() throws Exception {
        return ((Headphones2)sensor).getAmpMode().index();
    }

    @Override
    public void pingNeuroSmart(double marker) throws Exception {
        ((Headphones2)sensor).pingNeuroSmart((byte)marker);
    }

    @Override
    public void getAmplifierParamHP2(WritableMap map) throws Exception {
        Headphones2AmplifierParam param = ((Headphones2)sensor).getAmplifierParam();
        map.putInt("Current",param.getRawCurrent());
        map.putBoolean("ChSignalUse1",param.isChSignalUse1());
        map.putBoolean("ChSignalUse2",param.isChSignalUse2());
        map.putBoolean("ChSignalUse3",param.isChSignalUse3());
        map.putBoolean("ChSignalUse4",param.isChSignalUse4());
        map.putBoolean("ChResistUse1",param.isChResistUse1());
        map.putBoolean("ChResistUse2",param.isChResistUse2());
        map.putBoolean("ChResistUse3",param.isChResistUse3());
        map.putBoolean("ChResistUse4",param.isChResistUse4());
        map.putInt("ChGain1",param.getRawChGain1());
        map.putInt("ChGain2",param.getRawChGain2());
        map.putInt("ChGain3",param.getRawChGain3());
        map.putInt("ChGain4",param.getRawChGain4());
    }

    @Override
    public void setAmplifierParamHP2(ReadableMap param) throws Exception {
        ((Headphones2)sensor).setAmplifierParam(new Headphones2AmplifierParam(
                param.getBoolean("ChSignalUse1"),
                param.getBoolean("ChSignalUse2"),
                param.getBoolean("ChSignalUse3"),
                param.getBoolean("ChSignalUse4"),
                param.getBoolean("ChResistUse1"),
                param.getBoolean("ChResistUse2"),
                param.getBoolean("ChResistUse3"),
                param.getBoolean("ChResistUse4"),
                param.getInt("ChGain1"),
                param.getInt("ChGain2"),
                param.getInt("ChGain3"),
                param.getInt("ChGain4"),
                param.getInt("Current")
        ));
    }
}

==> react-native-neurosdk2-1.0.27.tgz: package/android/src/main/java/com/neurosdk2/Headphones2Impl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertFPGData;
import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.ConvertReactToBoolArray;
import static com.neurosdk2.Utils.ConvertReactToIntArray;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.Headphones2;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.FPGData;
import com.neurosdk2.neuro.types.Headphones2AmplifierParam;
import com.neurosdk2.neuro.types.Headphones2ResistData;
import com.neurosdk2.neuro.types.Headphones2SignalData;
import com.neurosdk2.neuro.types.IrAmplitude;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.RedAmplitude;
import com.facebook.react.bridge.CxxCallbackImpl;

public class Headphones2Impl extends AFullSensor{

    public Headphones2Impl(Sensor sensor, String guid, ReactApplicationContext context, CxxCallbackImpl sensorCallback){
        this.sensor = sensor;
        this.guid = guid;
        this.reactContext = context;
        this.cxxCallback = sensorCallback;
        addCallbacks();
    }

    @Override
    protected void addCallbacks() {
        super.addCallbacks();
        ((Headphones2)sensor).signalDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray signalArray = Arguments.createArray();
            for (Headphones2SignalData signal : data) {
                WritableMap map = Arguments.createMap();
                map.putInt("PackNum", signal.getPackNum());
                map.putInt("Marker", signal.getMarker());
                map.putDouble("Ch1", signal.getCh1());
                map.putDouble("Ch2", signal.getCh2());
                map.putDouble("Ch3", signal.getCh3());
                map.putDouble("Ch4", signal.getCh4());
                signalArray.pushMap(map);
            }
            result.putArray(DATA_ID, signalArray);
            if(cxxCallback == null){
                sendEvent(reactContext, Constants.HEADPHONES2_SIGNAL_RECEIVED_EVENT_NAME.raw(), result);
            }
            else 
            {
                cxxCallback.invoke(Constants.HEADPHONES2_SIGNAL_RECEIVED_EVENT_NAME.raw(), result);
            }
        };
        ((Headphones2)sensor).resistDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for(Headphones2ResistData resists : data){
                WritableMap map = Arguments.createMap();
                map.putInt("PackNum", resists.getPackNum());
                map.putDouble("Ch1", resists.getCh1());
                map.putDouble("Ch2", resists.getCh2());
                map.putDouble("Ch3", resists.getCh3());
                map.putDouble("Ch4", resists.getCh4());
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            if(cxxCallback == null){
                sendEvent(reactContext, Constants.HEADPHONES2_RESIST_RECEIVED_EVENT_NAME.raw(), result);
            }
            else 
            {
                cxxCallback.invoke(Constants.HEADPHONES2_RESIST_RECEIVED_EVENT_NAME.raw(), result);
            }
        };
        ((Headphones2)sensor).fpgDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for (FPGData fpgData : data) {
                WritableMap map = Arguments.createMap();
                ConvertFPGData(fpgData, map);
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            if(cxxCallback == null){
                sendEvent(reactContext, Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
            }
            else 
            {
                cxxCallback.invoke(Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
            }
        };
        ((Headphones2)sensor).memsDataReceived = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            WritableArray array = Arguments.createArray();
            for (MEMSData memsData : data) {
                WritableMap map = Arguments.createMap();
                ConvertMEMSData(memsData, map);
                array.pushMap(map);
            }
            result.putArray(DATA_ID, array);
            if(cxxCallback == null){
                sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
            }
            else 
            {
                cxxCallback.invoke(Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
            }
        };
        ((Headphones2)sensor).ampModeChanged = (data)->{
            WritableMap result = Arguments.createMap();
            result.putString(GUID_ID, guid);
            result.putInt(DATA_ID, data.index());
            if(cxxCallback == null){
                sendEvent(reactContext,Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
            }
            else 
            {
                cxxCallback.invoke(Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
            }
        };
    }

    @Override
    protected void removeCallbacks() {
        super.removeCallbacks();
        ((Headphones2)sensor).signalDataReceived = null;
        ((Headphones2)sensor).resistDataReceived = null;
        ((Headphones2)sensor).fpgDataReceived = null;
        ((Headphones2)sensor).memsDataReceived = null;
        ((Headphones2)sensor).ampModeChanged = null;
    }

    @Override
    protected String getSensorName() {
        return "Headphones2";
    }

    @Override
    public int getSamplingFrequencyMEMS() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyMEMS().index();
    }

    @Override
    public int getSamplingFrequencyFPG() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyFPG().index();
    }

    @Override
    public int getSamplingFrequencyResist() throws Exception {
        return ((Headphones2)sensor).getSamplingFrequencyResist().index();
    }

    @Override
    public int getIrAmplitude() throws Exception {
        return ((Headphones2)sensor).getIrAmplitude().index();
    }

    @Override
    public void setIrAmplitude(int amp) throws Exception {
        ((Headphones2)sensor).setIrAmplitude(IrAmplitude.indexOf(amp));
    }

    @Override
    public int getRedAmplitude() throws Exception {
        return ((Headphones2)sensor).getRedAmplitude().index();
    }

    @Override
    public void setRedAmplitude(int amp) throws Exception {
        ((Headphones2)sensor).setRedAmplitude(RedAmplitude.indexOf(amp));
    }

    @Override
    public int getAmpMode() throws Exception {
        return ((Headphones2)sensor).getAmpMode().index();
    }

    @Override
    public void pingNeuroSmart(double marker) throws Exception {
        ((Headphones2)sensor).pingNeuroSmart((byte)marker);
    }

    @Override
    public void getAmplifierParamHP2(WritableMap map) throws Exception {
        Headphones2AmplifierParam param = ((Headphones2)sensor).getAmplifierParam();
        map.putInt("Current",param.getRawCurrent());
        map.putBoolean("ChSignalUse1",param.isChSignalUse1());
        map.putBoolean("ChSignalUse2",param.isChSignalUse2());
        map.putBoolean("ChSignalUse3",param.isChSignalUse3());
        map.putBoolean("ChSignalUse4",param.isChSignalUse4());
        map.putBoolean("ChResistUse1",param.isChResistUse1());
        map.putBoolean("ChResistUse2",param.isChResistUse2());
        map.putBoolean("ChResistUse3",param.isChResistUse3());
        map.putBoolean("ChResistUse4",param.isChResistUse4());
        map.putInt("ChGain1",param.getRawChGain1());
        map.putInt("ChGain2",param.getRawChGain2());
        map.putInt("ChGain3",param.getRawChGain3());
        map.putInt("ChGain4",param.getRawChGain4());
    }

    @Override
    public void setAmplifierParamHP2(ReadableMap param) throws Exception {
        ((Headphones2)sensor).setAmplifierParam(new Headphones2AmplifierParam(
                param.getBoolean("ChSignalUse1"),
                param.getBoolean("ChSignalUse2"),
                param.getBoolean("ChSignalUse3"),
                param.getBoolean("ChSignalUse4"),
                param.getBoolean("ChResistUse1"),
                param.getBoolean("ChResistUse2"),
                param.getBoolean("ChResistUse3"),
                param.getBoolean("ChResistUse4"),
                param.getInt("ChGain1"),
                param.getInt("ChGain2"),
                param.getInt("ChGain3"),
                param.getInt("ChGain4"),
                param.getInt("Current")
        ));
    }
}
